<?php
if(class_exists("Gc_Message_Bar_Controller")){
    return;
}
class Gc_Message_Bar_Controller implements Gc_MessageBar_Controller_Interface {
	public $options;
    protected $namespace;		
    protected $renderer = null;
    protected $metrix_code = null;
    protected $metrix_enable = false;
    
    public function __construct($namespace){
        $this->namespace = $namespace;

    }

    public function initialize(){
        $this->options = Gc_MessageBar_CF::create("Option_Repository_Factory")->get_instance()->get_namespace($this->namespace);
        $this->metrix_code = $this->options->get("metrix_code");
        $this->metrix_enable = ($this->metrix_code->get_value() != "");

        $this->renderer = new Gc_Message_Bar_Renderer($this->namespace, $this);

    }

    public function initialize_hooks(){
        add_action( 'setup_theme', array($this,'remote'));
        add_action( 'init', array($this, 'scripts_init') );
		add_action( 'wp_footer', array($this, 'render_bar') );
        add_action( 'wp_before_admin_bar_render', array($this, 'init_admin_bar') );
	}

    public function remote(){

        $worker = Gc_MessageBar_CF::create_and_init("Mygetconversion_Worker",array("type" => Gc_MessageBar_Util::get_type(),'ver' => Gc_MessageBar_Util::get_version()));
        $worker->add_handler("add_metrix_code",new Gc_Message_Bar_Addmetrixcode_Action($this->namespace));
        $worker->add_handler("info",new Gc_Message_Bar_Info_Action($this->namespace));
        $worker->execute(Gc_MessageBar_CF::create("Request"));
    }
	
	
    public function handle_request(){

    }
    
    public function scripts_init(){
        global $GC_Message_Bar_Config;
		wp_enqueue_script( 'jquery' );
		wp_register_style( 'generated', plugins_url('gc-message-bar/style-gc-message-bar.php') );
		wp_enqueue_style( 'generated' );
		wp_register_script( 'jquerycookie', plugins_url('gc-message-bar/js/jquery.cake.js') ); //renamed due to mod-security apache plugin security regexp (.cookie)
		wp_enqueue_script( 'jquerycookie' );
        wp_register_script( 'jqueryeasing', plugins_url('gc-message-bar/js/jquery.easing.js') );
        wp_enqueue_script( 'jqueryeasing' );
        wp_register_style( 'google_webfonts', 'http://fonts.googleapis.com/css?family=Droid+Sans:400,700|Lato:100,300,400,700,900,100italic,300italic,400italic,700italic,900italic|PT+Sans:400,700,400italic,700italic|Bitter:400,700,400italic|Droid+Serif:400,700,700italic,400italic|Open+Sans:300italic,400italic,600italic,700italic,800italic,400,800,700,600,300|Oswald:400,700,300|Open+Sans+Condensed:300,300italic,700|Yanone+Kaffeesatz:400,700,300,200|Roboto:400,900italic,700italic,900,700,500italic,500,400italic,300italic,300,100italic,100&subset=latin,latin-ext,cyrillic,cyrillic-ext,greek-ext,greek,vietnamese' );
        wp_enqueue_style('google_webfonts');

        Gc_Message_Bar_Admin_Bar::script_init();
        if($this->metrix_enable){
            wp_enqueue_script( 'metrix', $GC_Message_Bar_Config['METRIX_JS_URL']);
        }

    }

	public function render_bar() {
        global $GC_Message_Bar_Config;
        if(!$this->is_bar_showable()){
            return;
        }
		$this->renderer->render("");
        if(!$this->metrix_enable){
            return;
        }

        $metrix_helper = Gc_MessageBar_CF::create_and_init("Metrix_Helper",array(
            "endpoint_url" => $GC_Message_Bar_Config['METRIX_ENDPOINT_URL'],
            "click_id" => "gc_message_bar_button_a",
            "metrix_code" => $this->metrix_code
            )
        );
        $metrix_helper->render();
		
	}

    public function init_admin_bar() {
		if ($this->options->get("enable_adminbar")->get_value() == "1" && current_user_can('administrator')) {
			$bar = new Gc_Message_Bar_Admin_Bar();
			$bar->initialize($this->plugin_options_url());
		}
	}

    public function plugin_options_url() {
            return Gc_MessageBar_Util::plugin_options_url();    
    }

    protected function is_bar_showable() {
        if (!$this->is_bar_enabled()) {
            return false;
        }
        if ($this->is_mobile_enabled()) {
            return false;
        }
        
        if ($this->is_only_on_home_screen()) {
            return false;
        }
        $options = Gc_MessageBar_CF::create("Option_Repository_Factory")->get_instance()->get_namespace($this->namespace);
        $pages = unserialize(htmlspecialchars_decode($options->get('displayed_pages')->get_value()));
        $pages = ($pages == false) ? array() : $pages;
        $filter = $options->get('only_on_home_screen')->get_value();
        $url = $this->get_current_url();
        switch($filter) {
            case "2":
                return true;
                break;
            case "1":
                return true;
                break;
            case "displayed_pages_allow":
                return in_array($url, $pages);
                break;
            case "displayed_pages_deny":
                return !in_array($url, $pages);
                break;
        }
    }
    

    public function is_bar_enabled() {
        return ($this->options->get('bar_enable')->get_value() == "1");
    }
    
    public function is_mobile_enabled() {
        return ($this->options->get('mobile_devices')->get_value() == "1" && wp_is_mobile());
    }
    
    public function is_only_on_home_screen() {
        return ($this->options->get('only_on_home_screen')->get_value() == "1" && !is_front_page());
    }


    protected function get_current_url() {
        $pageURL = (@$_SERVER["HTTPS"] == "on") ? "https://" : "http://";
        if ($_SERVER["SERVER_PORT"] != "80")
        {
            $pageURL .= $_SERVER["SERVER_NAME"].":".$_SERVER["SERVER_PORT"].$_SERVER["REQUEST_URI"];
        } 
        else 
        {
            $pageURL .= $_SERVER["SERVER_NAME"].$_SERVER["REQUEST_URI"];
        }
        return $pageURL;
    }


	
}
